.. _reason_codes_api:

#############################
(Deprecated) Reason Codes API
#############################

This interface is considered deprecated.  Please use :ref:`PredictionExplanations <pred_expl_api>`
instead.

.. autoclass:: datarobot.ReasonCodesInitialization
   :members:

.. autoclass:: datarobot.ReasonCodes
   :members:

.. autoclass:: datarobot.models.reason_codes.ReasonCodesRow
   :members:

.. autoclass:: datarobot.models.reason_codes.ReasonCodesPage
   :members:

